import React, { useState, useEffect } from 'react'
import { Client, useClient } from 'cozy-client'
import { useSelector } from 'react-redux'
import { Ecogesture } from 'models'
import './actionBegin.scss'
import { AppStore } from 'store'
import ActionService from 'services/action.service'
import ActionCard from 'components/Action/ActionCard'

interface ActionListProps {
  setSelectedAction: React.Dispatch<React.SetStateAction<Ecogesture | null>>
  setShowList: React.Dispatch<React.SetStateAction<boolean>>
}

const ActionList: React.FC<ActionListProps> = ({
  setSelectedAction,
  setShowList,
}: ActionListProps) => {
  const client: Client = useClient()
  const { isProfileTypeCompleted } = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const { fluidTypes } = useSelector((state: AppStore) => state.ecolyo.global)
  const [actions, setActions] = useState<Ecogesture[]>()

  useEffect(() => {
    let subscribed = true
    const getActions = async () => {
      const actionService = new ActionService(client)
      let actionList: Ecogesture[] = []
      if (isProfileTypeCompleted) {
        actionList = await actionService.getCustomActions(fluidTypes)
      } else {
        actionList = await actionService.getDefaultActions()
      }
      if (subscribed) {
        setActions(actionList)
      }
    }
    getActions()
    return () => {
      subscribed = false
    }
  }, [client, isProfileTypeCompleted, fluidTypes])

  return (
    <>
      {actions && (
        <div className="action-list-container">
          {actions.map(action => {
            return (
              <ActionCard
                key={action.id}
                action={action}
                setSelectedAction={setSelectedAction}
                setShowList={setShowList}
              />
            )
          })}
        </div>
      )}
    </>
  )
}

export default ActionList
