import ActionChoose from 'components/Action/ActionChoose'
import ActionDone from 'components/Action/ActionDone'
import ActionOnGoing from 'components/Action/ActionOnGoing'
import Content from 'components/Content/Content'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import { UserActionState } from 'enum/userAction.enum'
import { UserChallenge } from 'models'
import React, { useCallback, useState } from 'react'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'

const ActionView: React.FC = () => {
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const { currentChallenge } = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )
  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])

  const renderAction = (challenge: UserChallenge) => {
    switch (challenge.action.state) {
      case UserActionState.UNSTARTED:
        return <ActionChoose userChallenge={challenge} />
      case UserActionState.ONGOING:
        return <ActionOnGoing userAction={challenge.action} />
      case UserActionState.NOTIFICATION:
        return <ActionDone currentChallenge={challenge} />
      default:
        return <ActionChoose userChallenge={challenge} />
    }
  }

  return (
    <>
      <CozyBar titleKey={'common.title_action'} displayBackArrow={true} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_action'}
        displayBackArrow={true}
      />
      <Content height={headerHeight}>
        {currentChallenge && renderAction(currentChallenge)}
      </Content>
    </>
  )
}

export default ActionView
