import Navbar from 'components/Navbar/Navbar'
import WelcomeModal from 'components/Onboarding/WelcomeModal'
import AppRoutes from 'components/Routes/Routes'
import SplashRoot from 'components/Splash/SplashRoot'
import SplashScreen from 'components/Splash/SplashScreen'
import SplashScreenError from 'components/Splash/SplashScreenError'
import { Content, Layout, Main } from 'cozy-ui/transpiled/react/Layout'
import React, { useEffect } from 'react'
import { useSelector } from 'react-redux'
import EnvironmentService from 'services/environment.service'
import { AppStore } from 'store'
import MatomoTracker from 'utils/matomoTracker'

interface AppProps {
  tracker: MatomoTracker
}

export const App = ({ tracker }: AppProps) => {
  const { onboarding } = useSelector((state: AppStore) => state.ecolyo.profile)
  const { termsStatus } = useSelector((state: AppStore) => state.ecolyo.global)
  const isDev = new EnvironmentService().isLocal()

  useEffect(() => {
    if (tracker && !isDev) {
      if (termsStatus.accepted) {
        tracker.connectToHistory()
      }
      return () => {
        tracker.disconnectFromHistory()
      }
    }
  }, [termsStatus.accepted, tracker, isDev])

  return (
    <Layout>
      <SplashRoot
        splashComponent={SplashScreen}
        splashErrorComponent={SplashScreenError}
      >
        {termsStatus.accepted && (
          <>
            <WelcomeModal open={!onboarding.isWelcomeSeen} />
            <Navbar />
          </>
        )}
        <Main>
          <Content className="app-content">
            <AppRoutes termsStatus={termsStatus} />
          </Content>
        </Main>
      </SplashRoot>
    </Layout>
  )
}

export default App
