import React from 'react'
import { shallow, mount } from 'enzyme'
import ConnectionNotFound from 'components/Connection/ConnectionNotFound'
import Button from '@material-ui/core/Button'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('ConnectionNotFound component test', () => {
  const konnectorSlug = 'enedissgegrandlyon'

  it('should correctly render connection not found', () => {
    const result = shallow(
      <ConnectionNotFound konnectorSlug={konnectorSlug} />
    ).getElement()
    expect(result).toMatchSnapshot()
  })

  it('should open konnector url when button is clicked', () => {
    global.open = jest.fn()

    const wrapper = mount(<ConnectionNotFound konnectorSlug={konnectorSlug} />)
    const submitStyledButton = wrapper.find(Button)
    submitStyledButton.simulate('click')

    expect(global.open).toHaveBeenCalledWith(
      'http://localhost/#/discover/enedissgegrandlyon',
      '_blank'
    )
  })
})
