import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import {
  mockCustomPopup,
  mockCustomPopupOff,
  mockCustomPopupOutdated,
} from '../../../tests/__mocks__/customPopup.mock'
import CustomPopupModal from './CustomPopupModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockHandleClose = jest.fn()

describe('CustomPopupModal component', () => {
  const wrapper = mount(
    <CustomPopupModal
      customPopup={mockCustomPopup}
      handleCloseClick={mockHandleClose}
    />
  )
  it('should render correctly', () => {
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should close modal', () => {
    wrapper.find(Button).simulate('click')
    expect(mockHandleClose).toHaveBeenCalled()
  })

  it('should not be rendered, popup not enabled', () => {
    const wrapper = mount(
      <CustomPopupModal
        customPopup={mockCustomPopupOff}
        handleCloseClick={mockHandleClose}
      />
    )
    expect(wrapper.find('div.customPopupModal').exists()).toBeFalsy()
  })

  it('should not be rendered, popup outdated', () => {
    const wrapper = mount(
      <CustomPopupModal
        customPopup={mockCustomPopupOutdated}
        handleCloseClick={mockHandleClose}
      />
    )
    expect(wrapper.find('div.customPopupModal').exists()).toBeFalsy()
  })
})
