import React, { useState, useEffect } from 'react'
import './duelChart.scss'
import { TimeStep } from 'enum/timeStep.enum'
import { Dataload, UserChallenge } from 'models'
import DuelBar from 'components/Duel/DuelBar'

interface DuelChartProps {
  userChallenge: UserChallenge
  finishedDataLoad?: Dataload[]
  width: number
  height: number
}

const DuelChart: React.FC<DuelChartProps> = ({
  userChallenge,
  finishedDataLoad,
  width,
  height,
}: DuelChartProps) => {
  const [average, setAverage] = useState<number>(0)

  useEffect(() => {
    setAverage(userChallenge.duel.threshold / userChallenge.duel.duration.days)
  }, [userChallenge.duel.duration.days, userChallenge.duel.threshold])

  return (
    <div className="fs-slide">
      <DuelBar
        userChallenge={userChallenge}
        finishedDataLoad={finishedDataLoad}
        average={average}
        timeStep={TimeStep.DAY}
        height={height}
        width={width}
      />
    </div>
  )
}

export default DuelChart
