import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { mockInitialProfileState } from '../../../tests/__mocks__/store'
import EcogestureInitModal from './EcogestureInitModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
  }
})
const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => ({
    push: mockHistoryPush,
  }),
}))

const mockStore = configureStore([])
const mockHandleClose = jest.fn()
const mockHandleLaunchForm = jest.fn()
describe('EcogestureInitModal component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        profile: mockInitialProfileState,
        challenge: challengeStateData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureInitModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleLaunchForm={mockHandleLaunchForm}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should close modal ', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
        profile: mockInitialProfileState,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureInitModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleLaunchForm={mockHandleLaunchForm}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHandleClose).toHaveBeenCalledTimes(1)
  })
  it('should close modal and maunch form', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        profile: mockInitialProfileState,
        challenge: challengeStateData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureInitModal
          open={true}
          handleCloseClick={mockHandleClose}
          handleLaunchForm={mockHandleLaunchForm}
        />
      </Provider>
    )
    wrapper.find(Button).at(1).simulate('click')
    expect(mockHandleLaunchForm).toHaveBeenCalledTimes(1)
  })
})
