import FormNavigation from 'components/FormGlobal/FormNavigation'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { EquipmentType } from 'enum/ecogesture.enum'
import { EcogestureStepForm } from 'enum/ecogestureForm.enum'
import { ProfileTypeStepForm } from 'enum/profileType.enum'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import React, { useCallback, useState } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { useNavigate } from 'react-router-dom'
import { AppStore } from 'store'
import { updateProfile } from 'store/profile/profile.actions'
import {
  newProfileEcogestureEntry,
  updateProfileEcogesture,
} from 'store/profileEcogesture/profileEcogesture.actions'
import './ecogestureFormEquipment.scss'
import EquipmentIcon from './EquipmentIcon'

interface EcogestureFormEquipmentProps {
  profileEcogesture: ProfileEcogesture
  setPreviousStep: Function
  setNextStep?: Function
  step: ProfileTypeStepForm | EcogestureStepForm
}

const EcogestureFormEquipment: React.FC<EcogestureFormEquipmentProps> = ({
  profileEcogesture,
  setPreviousStep,
  setNextStep,
  step,
}: EcogestureFormEquipmentProps) => {
  const { t } = useI18n()
  const dispatch = useDispatch()
  const navigate = useNavigate()
  const { isProfileEcogestureCompleted } = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<string[]>(
    isProfileEcogestureCompleted ? profileEcogesture.equipments : []
  )

  const handlePrevious = useCallback(() => {
    setPreviousStep(profileEcogesture)
  }, [profileEcogesture, setPreviousStep])

  const handleNext = useCallback(() => {
    profileEcogesture.equipments = answer as EquipmentType[]
    // Check if gestureForm is used from Big profile or small profile
    if (setNextStep) {
      setNextStep()
      dispatch(updateProfileEcogesture(profileEcogesture))
    } else {
      dispatch(newProfileEcogestureEntry(profileEcogesture))
      dispatch(updateProfile({ isProfileEcogestureCompleted: true }))
      navigate('/ecogesture-selection')
    }
  }, [profileEcogesture, setNextStep, answer, dispatch, navigate])

  const isChecked = useCallback(
    (value: string): boolean => {
      if (answer.includes(value)) {
        return true
      } else {
        return false
      }
    },
    [answer]
  )

  const handleChange = useCallback(
    (value: string) => {
      const tempAnswer: string[] = [...answer]
      if (tempAnswer.includes(value)) {
        const index = tempAnswer.indexOf(value)
        if (index > -1) tempAnswer.splice(index, 1)
      } else {
        tempAnswer.push(value)
      }
      setAnswer(tempAnswer)
    },
    [answer]
  )

  return (
    <>
      <div className="ecogesture-profile-container">
        <div className={'equipment-form-container'}>
          <div className={'equipment-label text-22-normal'}>
            {t(
              `ecogesture_profile.${EcogestureStepForm[
                EcogestureStepForm.EQUIPMENTS
              ].toLowerCase()}.question`
            )}
          </div>
          <div className={'equipment-hint text-16-normal'}>
            {t(
              `ecogesture_profile.${EcogestureStepForm[
                EcogestureStepForm.EQUIPMENTS
              ].toLowerCase()}.hint`
            )}
          </div>
          <div className="icons-container">
            {Object.values(EquipmentType).map((equipment, index) => {
              return (
                <label key={index} className={'checkbox-equipment'}>
                  <input
                    type={'checkbox'}
                    value={equipment}
                    name={equipment.toString()}
                    onChange={() => handleChange(equipment)}
                    checked={isChecked(equipment)}
                    className={
                      isChecked(equipment) ? 'item-eq checked' : 'item-eq'
                    }
                  />
                  <EquipmentIcon
                    equipment={equipment}
                    isChecked={answer.includes(equipment)}
                  />
                </label>
              )
            })}
          </div>
        </div>
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === []}
        isEcogesture={true}
      />
    </>
  )
}

export default EcogestureFormEquipment
