/* eslint-disable react/display-name */
import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import { Profile } from 'models'
import React from 'react'
import { Provider } from 'react-redux'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureFormView from './EcogestureFormView'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock(
  'components/EcogestureForm/EcogestureLaunchFormModal',
  () => 'mock-ecogesturelaunchmodal'
)
jest.mock('components/Content/Content', () => 'mock-content')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
  useLocation: () => {
    return {
      search: '',
    }
  },
}))

describe('EcogestureFormView component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })

  it('should be rendered correctly', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render singlechoice', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })
  it('should render profiletype form step because profiletype is completed', async () => {
    const updatedProfile: Profile = {
      ...mockInitialEcolyoState.profile,
      isProfileTypeCompleted: true,
    }
    const updatedStore = { ...mockInitialEcolyoState, profile: updatedProfile }
    const wrapper = mount(
      <Provider store={createMockStore(updatedStore)}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.profile-type-container').exists()).toBeTruthy()
  })
  it('should go to next step', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('input').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })
  it('should go to previous step', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormView />
      </Provider>
    )
    //go first to next step
    await waitForComponentToPaint(wrapper)
    wrapper.find('input').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
    await waitForComponentToPaint(wrapper)
    //then go back
    wrapper.find(Button).first().simulate('click')
    expect(wrapper.find('.ecogesture-form-single').exists()).toBeTruthy()
  })
})
