import Content from 'components/Content/Content'
import EcogestureFormEquipment from 'components/EcogestureForm/EcogestureFormEquipment'
import EcogestureFormSingleChoice from 'components/EcogestureForm/EcogestureFormSingleChoice'
import EcogestureLaunchFormModal from 'components/EcogestureForm/EcogestureLaunchFormModal'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import Loader from 'components/Loader/Loader'
import ProfileTypeView from 'components/ProfileType/ProfileTypeView'
import {
  EcogestureStepForm,
  ProfileEcogestureAnswerType,
} from 'enum/ecogestureForm.enum'
import { Profile } from 'models'
import {
  ProfileEcogesture,
  ProfileEcogestureAnswer,
} from 'models/profileEcogesture.model'
import React, { useCallback, useEffect, useState } from 'react'
import { useSelector } from 'react-redux'
import { useLocation } from 'react-router-dom'
import ProfileEcogestureFormService from 'services/profileEcogestureForm.service'
import { AppStore } from 'store'

const EcogestureFormView: React.FC = () => {
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const defineHeaderHeight = (height: number) => {
    setHeaderHeight(height)
  }
  const { isProfileTypeCompleted }: Profile = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const curProfileEcogesture: ProfileEcogesture = useSelector(
    (state: AppStore) => state.ecolyo.profileEcogesture
  )
  const shouldOpenModal = new URLSearchParams(useLocation().search).get('modal')
  const [step, setStep] = useState<EcogestureStepForm>(
    EcogestureStepForm.HEATING_TYPE
  )
  const [answerType, setAnswerType] = useState<ProfileEcogestureAnswer>({
    type: ProfileEcogestureAnswerType.SINGLE_CHOICE,
    attribute: '',
    choices: [],
  })

  const [isLoading, setIsLoading] = useState<boolean>(true)
  const [openLaunchModal, setOpenLaunchModal] = useState<boolean>(
    shouldOpenModal !== 'false' ? true : false
  )
  const [viewedStep, setViewedStep] = useState<number>(-1)
  const [profileEcogesture, setProfileEcogesture] =
    useState<ProfileEcogesture>(curProfileEcogesture)
  const setNextStep = useCallback(
    (_profileEcogesture: ProfileEcogesture) => {
      setProfileEcogesture(_profileEcogesture)
      const pefs = new ProfileEcogestureFormService(_profileEcogesture)
      const nextStep: EcogestureStepForm = pefs.getNextFormStep(step)
      setIsLoading(true)
      if (nextStep > viewedStep) {
        setViewedStep(nextStep)
      }
      const _answerType: ProfileEcogestureAnswer =
        ProfileEcogestureFormService.getAnswerForStep(nextStep)
      setAnswerType(_answerType)
      setStep(nextStep)
    },
    [step, viewedStep]
  )
  const setPreviousStep = useCallback(
    (_profileEcogesture: ProfileEcogesture) => {
      setProfileEcogesture(_profileEcogesture)
      const pefs = new ProfileEcogestureFormService(_profileEcogesture)
      const previousStep: EcogestureStepForm = pefs.getPreviousFormStep(step)
      setIsLoading(true)
      const _answerType: ProfileEcogestureAnswer =
        ProfileEcogestureFormService.getAnswerForStep(previousStep)
      setAnswerType(_answerType)
      setStep(previousStep)
    },
    [step]
  )

  useEffect(() => {
    const _answerType: ProfileEcogestureAnswer =
      ProfileEcogestureFormService.getAnswerForStep(step)
    setAnswerType(_answerType)
    setIsLoading(false)
  }, [step])

  if (isLoading) {
    return (
      <Content height={headerHeight}>
        <Loader />
      </Content>
    )
  }
  return (
    <>
      <CozyBar titleKey={'common.title_ecogestures'} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_ecogestures'}
      />
      <Content height={headerHeight}>
        {isProfileTypeCompleted ? (
          <ProfileTypeView />
        ) : (
          <>
            {step === EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormEquipment
                step={EcogestureStepForm.EQUIPMENTS}
                profileEcogesture={profileEcogesture}
                setPreviousStep={setPreviousStep}
              />
            )}
            {step !== EcogestureStepForm.EQUIPMENTS && (
              <EcogestureFormSingleChoice
                step={step}
                viewedStep={viewedStep}
                profileEcogesture={profileEcogesture}
                answerType={answerType}
                setNextStep={setNextStep}
                setPrevioustStep={setPreviousStep}
              />
            )}
          </>
        )}
      </Content>
      <EcogestureLaunchFormModal
        open={openLaunchModal}
        handleCloseClick={() => setOpenLaunchModal(false)}
      />
    </>
  )
}

export default EcogestureFormView
