import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ExplorationFinished from './ExplorationFinished'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockStore = configureStore([])

describe('ExplorationFinished', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationFinished userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    expect(wrapper.find('.congratulation').exists()).toBeTruthy()
    expect(wrapper.find('.exploration-earn').exists()).toBeTruthy()
    expect(wrapper.find('.msg-sucess').text()).toEqual(
      userChallengeData[0].exploration.message_success
    )
  })
  it('should redirect to challenge on click on styledButton', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ExplorationFinished userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
  })
})
