import { Button } from '@material-ui/core'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.actions'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../../tests/__mocks__/store'
import UnSubscribe from './UnSubscribe'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => {
    return {
      updateProfile: mockUpdateProfile,
    }
  })
})
const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('UnSubscribe component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    updateProfileSpy.mockClear()
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <UnSubscribe />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should click on button and deactivate report', () => {
    const wrapper = mount(
      <Provider store={store}>
        <UnSubscribe />
      </Provider>
    )
    wrapper.find(Button).simulate('click')
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: false,
    })
  })
})
