import { chartReducer } from './chart.reducer'
import {
  SET_CURRENT_TIMESTEP,
  SET_SELECTED_DATE,
  SET_CURRENT_INDEX,
  SET_CURRENT_DATACHART,
  SET_CURRENT_DATACHART_INDEX,
  SET_LOADING,
} from './chart.actions'
import { DateTime } from 'luxon'
import { TimeStep } from 'enum/timeStep.enum'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import { graphData } from '../../../tests/__mocks__/datachartData.mock'

describe('chart reducer', () => {
  it('should return the initial state', () => {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const result = chartReducer(undefined as any, { type: 'default' })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_SELECTED_DATE with payload', () => {
    const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
      zone: 'utc',
    })
    const result = chartReducer(mockInitialChartState, {
      type: SET_SELECTED_DATE,
      payload: mockDate,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      selectedDate: mockDate,
    })
  })

  it('should handle SET_SELECTED_DATE without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_SELECTED_DATE,
    })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_CURRENT_TIMESTEP with payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_TIMESTEP,
      payload: TimeStep.MONTH,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      currentTimeStep: TimeStep.MONTH,
    })
  })

  it('should handle SET_CURRENT_TIMESTEP without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_TIMESTEP,
    })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_CURRENT_INDEX with payload', () => {
    const mockDate = DateTime.fromISO('2021-01-01T00:00:00.000Z', {
      zone: 'utc',
    })
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_INDEX,
      payload: mockDate,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      currentIndex: mockDate,
    })
  })

  it('should handle SET_CURRENT_INDEX without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_INDEX,
    })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_CURRENT_DATACHART with payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_DATACHART,
      payload: graphData,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      currentDatachart: graphData,
    })
  })

  it('should handle SET_CURRENT_DATACHART without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_DATACHART,
    })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_CURRENT_DATACHART_INDEX with payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_DATACHART_INDEX,
      payload: 1,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      currentDatachartIndex: 1,
    })
  })

  it('should handle SET_CURRENT_DATACHART_INDEX without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_CURRENT_DATACHART_INDEX,
    })
    expect(result).toEqual(mockInitialChartState)
  })

  it('should handle SET_LOADING with payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_LOADING,
      payload: false,
    })
    expect(result).toEqual({
      ...mockInitialChartState,
      loading: false,
    })
  })

  it('should handle SET_LOADING without payload', () => {
    const result = chartReducer(mockInitialChartState, {
      type: SET_LOADING,
    })
    expect(result).toEqual(mockInitialChartState)
  })
})
