import { Reducer } from 'redux'
import {
  SET_SELECTED_DATE,
  SET_CURRENT_TIMESTEP,
  SET_CURRENT_INDEX,
  SET_CURRENT_DATACHART,
  SET_CURRENT_DATACHART_INDEX,
  SET_LOADING,
  ChartActionTypes,
} from 'store/chart/chart.actions'
import { ChartState } from 'models/chart.model'
import { TimeStep } from 'enum/timeStep.enum'
import { DateTime } from 'luxon'

const initialState: ChartState = {
  selectedDate: DateTime.local().endOf('minute').setZone('utc', {
    keepLocalTime: true,
  }),
  currentTimeStep: TimeStep.WEEK,
  currentIndex: 0,
  currentDatachart: { actualData: [], comparisonData: null },
  currentDatachartIndex: 0,
  loading: true,
}

export const chartReducer: Reducer<ChartState> = (
  state = initialState,
  action: ChartActionTypes
): ChartState => {
  switch (action.type) {
    case SET_SELECTED_DATE:
      return action.payload != undefined
        ? {
            ...state,
            selectedDate: action.payload,
          }
        : state
    case SET_CURRENT_TIMESTEP:
      return action.payload != undefined
        ? {
            ...state,
            currentTimeStep: action.payload,
          }
        : state
    case SET_CURRENT_INDEX:
      return action.payload != undefined
        ? {
            ...state,
            currentIndex: action.payload,
          }
        : state
    case SET_CURRENT_DATACHART:
      return action.payload != undefined
        ? {
            ...state,
            currentDatachart: action.payload,
          }
        : state
    case SET_CURRENT_DATACHART_INDEX:
      return action.payload != undefined
        ? {
            ...state,
            currentDatachartIndex: action.payload,
          }
        : state
    case SET_LOADING:
      return action.payload != undefined
        ? {
            ...state,
            loading: action.payload,
          }
        : state
    default:
      return state
  }
}
