import * as Sentry from '@sentry/react'
import { Client } from 'cozy-client'
import {
  ChallengeState,
  GlobalState,
  ModalState,
  Profile,
  ProfileType,
} from 'models'
import { ChartState } from 'models/chart.model'
import { ProfileEcogesture } from 'models/profileEcogesture.model'
import {
  applyMiddleware,
  combineReducers,
  compose,
  createStore,
  Store,
} from 'redux'
import { composeWithDevTools } from 'redux-devtools-extension'
import thunkMiddleware from 'redux-thunk'
import { globalReducer } from 'store/global/global.reducer'
import { modalReducer } from 'store/modal/modal.reducer'
import { challengeReducer } from './challenge/challenge.reducer'
import { chartReducer } from './chart/chart.reducer'
import { profileReducer } from './profile/profile.reducer'
import { profileEcogestureReducer } from './profileEcogesture/profileEcogesture.reducer'
import { profileTypeReducer } from './profileType/profileType.reducer'

export interface EcolyoState {
  global: GlobalState
  profile: Profile
  profileType: ProfileType
  profileEcogesture: ProfileEcogesture
  chart: ChartState
  modal: ModalState
  challenge: ChallengeState
}

export const ecolyoReducer = combineReducers({
  global: globalReducer,
  profile: profileReducer,
  profileType: profileTypeReducer,
  profileEcogesture: profileEcogestureReducer,
  chart: chartReducer,
  modal: modalReducer,
  challenge: challengeReducer,
})

export interface AppStore {
  ecolyo: EcolyoState
  cozy: never
}

const sentryReduxEnhancer = Sentry.createReduxEnhancer({})

const configureStore = (
  client: Client,
  persistedState: any
): Store<AppStore> => {
  const middlewares = [thunkMiddleware.withExtraArgument({ client })]
  const composeEnhancers = composeWithDevTools({ trace: true }) || compose

  const store: Store<AppStore> = createStore(
    combineReducers({
      ecolyo: ecolyoReducer,
      cozy: client.reducer(),
      persistedState,
    }),
    composeEnhancers(
      // eslint-disable-next-line prefer-spread
      applyMiddleware.apply(null, middlewares),
      sentryReduxEnhancer
    )
  )
  return store
}
export default configureStore
