import { Client } from 'cozy-client'
import { Profile } from 'models'
import ProfileService from 'services/profile.service'
import { Dispatch } from 'react'
import { AppStore } from 'store'

export const UPDATE_PROFILE = 'UPDATE_PROFILE'
export const SET_FIRST_CONNECTION = 'SET_FIRST_CONNECTION'

export interface UpdateProfile {
  type: typeof UPDATE_PROFILE
  payload?: Profile
}

export type ProfileActionTypes = UpdateProfile

export function updateProfileSuccess(updatedProfile: Profile): UpdateProfile {
  return {
    type: UPDATE_PROFILE,
    payload: updatedProfile,
  }
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function updateProfile(upd: Partial<Profile>): any {
  return async (
    dispatch: Dispatch<UpdateProfile>,
    getState: () => AppStore,
    { client }: { client: Client }
  ) => {
    const profileService = new ProfileService(client)
    const updatedProfile = await profileService.updateProfile(upd)
    if (updatedProfile) {
      dispatch(updateProfileSuccess(updatedProfile))
    }
  }
}
